#ifndef __KYLIN_AI_AUDIO_CONFIG_H__
#define __KYLIN_AI_AUDIO_CONFIG_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>

#include "audiodatastream.h"

typedef struct _AudioConfig AudioConfig;

/// 流式接口使用的配置 ///
// 使用默认麦克风的音频输入
AudioConfig *
audio_config_create_continuous_audio_input_from_default_microphone();
// 使用数据流的数据作为输入
AudioConfig *audio_config_create_continuous_audio_input_from_audio_data_stream(
    AudioDataStream *audio_data_stream);
//////

/// 非流式接口使用的配置 ///
// 使用整块原始数据作为输入
AudioConfig *audio_config_create_once_audio_input_from_pcm_data(
    const uint8_t *audio_data, uint32_t data_length);
// 使用pcm文件的数据作为输入
AudioConfig *audio_config_create_once_audio_input_from_pcm_file(
    const char *pcm_file);

// 使用整块原始数据作为输出
AudioConfig *audio_config_create_audio_output_from_pcm_data();
// 使用系统默认扬声器作为音频输出
AudioConfig *audio_config_create_audio_output_from_default_speaker();
// 使用pcm文件作为音频输出
AudioConfig *audio_config_create_audio_output_from_pcm_file_name(
    const char *pcm_file);

void audio_config_destroy(AudioConfig **config);

// 设置音频的格式
void audio_config_set_input_audio_rate(AudioConfig *config, int rate);

// 设置输出音频的格式：语速，可选值：[0-100]，默认为50
void audio_config_set_output_audio_speed(AudioConfig *config, int speed);

// 设置输出音频的格式：音量，可选值：[0-100]，默认为50
void audio_config_set_output_audio_volume(AudioConfig *config, int volume);

// 设置输出音频的格式：音高，可选值：[0-100]，默认为50
void audio_config_set_output_audio_pitch(AudioConfig *config, int pitch);


#ifdef __cplusplus
}
#endif

#endif
