#ifndef __SPEECH_RECOGNIZER_H__
#define __SPEECH_RECOGNIZER_H__

#include "audioconfig.h"
#include "config.h"
#include "result.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct _SpeechRecognitionSession SpeechRecognitionSession;

SpeechRecognitionSession *speech_recognizer_create_session();
void speech_recognizer_destroy_session(SpeechRecognitionSession **session);
int speech_recognizer_init_session(SpeechRecognitionSession *session);

// 识别结果回调
void speech_recognizer_result_set_callback(
    SpeechRecognitionSession *session, SpeechRecognitionResultCallback callback,
    void *user_data);

// 配置模型
void speech_recognizer_set_model_config(SpeechRecognitionSession *session,
                                        SpeechModelConfig *config);
// 设置输入音频的配置
void speech_recognizer_set_audio_config(SpeechRecognitionSession *session,
                                        AudioConfig *audio_config);

// 开始连续语音识别
void speech_recognizer_start_continuous_recognition_async(
    SpeechRecognitionSession *session);

// 停止连续语音识别
void speech_recognizer_stop_continuous_recognition_async(
    SpeechRecognitionSession *session);

// 1一次性识别，适用于识别一个音频文件或者一段内存数据
void speech_recognizer_recognize_once_async(SpeechRecognitionSession *session);

#ifdef __cplusplus
}
#endif

#endif
